==> nylon-cli-1.0.9.tgz: package/java/nylon-report/src/nylon/report/iReportc.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package nylon.report;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * @author somchit
 */
public class iReportc {

    public int add(int x, int y) {
        return x + y;
    }

    public byte[] test(Object objx) throws JSONException {
        //Object obj=objx.clone();
        System.out.println("============");
        // System.out.println(objx);
        JSONArray data = new JSONArray(objx.toString());
        for (int i = 0; i < data.length(); i++) {
            JSONObject o = data.getJSONObject(i);
            Iterator e = o.keys();
            while (e.hasNext()) {
                String name = (String) e.next();
                System.out.print(name);
                System.out.println(":" + o.getString(name));

            }
        }

        return new byte[]{0x12, 0x23};
    }

    public static void main(String[] args) throws FileNotFoundException, IOException {
        String data = "[{\"name\":\"somchit\",\"surname\":\"chanudom\",\"address\":\"5/424\"},{\"name\":\"somchit\",\"surname\":\"chanudom\",\"address\":\"5/424\"}]";
        String parameter = "{\"department\":\"it\"}";
        iReport ir = new iReport();
        //  byte[] bb = ir.export("C:\\Users\\somchit\\Documents\\Projects\\nylon\\app\\report\\report1.jasper", "pdf", data, parameter);

        //  FileOutputStream out = new FileOutputStream("test.pdf");
        // out.write(bb);
        //  out.close();
    }
}

==> nylon-cli-1.1.2.tgz: package/java/nylon-report/src/nylon/report/iReportc.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package nylon.report;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import org.codehaus.jettison.json.JSONArray;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 *
 * @author somchit
 */
public class iReportc {

    public int add(int x, int y) {
        return x + y;
    }

    public byte[] test(Object objx) throws JSONException {
        //Object obj=objx.clone();
        System.out.println("============");
        // System.out.println(objx);
        JSONArray data = new JSONArray(objx.toString());
        for (int i = 0; i < data.length(); i++) {
            JSONObject o = data.getJSONObject(i);
            Iterator e = o.keys();
            while (e.hasNext()) {
                String name = (String) e.next();
                System.out.print(name);
                System.out.println(":" + o.getString(name));

            }
        }

        return new byte[]{0x12, 0x23};
    }

    public static void main(String[] args) throws FileNotFoundException, IOException {
        String data = "[{\"name\":\"somchit\",\"surname\":\"chanudom\",\"address\":\"5/424\"},{\"name\":\"somchit\",\"surname\":\"chanudom\",\"address\":\"5/424\"}]";
        String parameter = "{\"department\":\"it\"}";
        iReport ir = new iReport();
          String bb = ir.export("C:\\Users\\somchit\\Documents\\Projects\\nylon\\app\\reports\\report1.jasper", "pdf", data, parameter);
          System.out.println(bb);

        //  FileOutputStream out = new FileOutputStream("test.pdf");
        // out.write(bb);
        //  out.close();
    }
}
